@@ -1,8 +1,9 @@
-/* alloc.c:89:OF */ extern char *alloc_page (long n); /* (n) int n; */
-/* alloc.c:149:OF */ extern void add_page_to_freelist (char *p, struct typemanager *tm); /* (p, tm) char *p; struct typemanager *tm; */
+/* alloc.c:89:OF */ extern void *alloc_page (long n); /* (n) int n; */
+/* alloc.c:149:OF */ inline void add_page_to_freelist (char *p, struct typemanager *tm); /* (p, tm) char *p; struct typemanager *tm; */
 /* alloc.c:196:OF */ extern object type_name (int t); /* (t) int t; */
-/* alloc.c:213:OF */ extern object alloc_object (enum type t); /* (t) enum type t; */
-/* alloc.c:296:OF */ extern object make_cons (object a, object d); /* (a, d) object a; object d; */
+/* alloc.c:213:OF */ inline object alloc_object (enum type t); /* (t) enum type t; */
+/* alloc.c:213:OF */ inline void add_pages(struct typemanager *,fixnum);
+/* alloc.c:296:OF */ extern inline object make_cons (object a, object d); /* (a, d) object a; object d; */
 /* alloc.c:364:OF */ extern object on_stack_cons (object x, object y); /* (x, y) object x; object y; */
 /* alloc.c:376:OF */ extern object fSallocated (object typ); /* (typ) object typ; */
 /* alloc.c:401:OF */ extern object fSreset_number_used (object typ); /* (typ) object typ; */
@@ -238,7 +239,7 @@ typedef void (*funcvoid)(void);
 /* gbc.c:151:OF */ extern void enter_mark_origin (object *p); /* (p) object *p; */
 /* gbc.c:938:OF */ extern void GBC (enum type t); /* (t) enum type t; */
 /* gbc.c:1326:OF */ extern object fLgbc (object x0); /* (x0) object x0; */
-/* sgbc.c:924:OF */ extern int sgc_count_type (int t); /* (t) int t; */
+/* sgbc.c:924:OF */ extern fixnum sgc_count_type (int t); /* (t) int t; */
 /* sgbc.c:938:OF */ extern int sgc_start (void); /* () */
 /* sgbc.c:1068:OF */ extern int sgc_quit (void); /* () */
 /* sgbc.c:1131:OF */ extern void make_writable (unsigned long beg, unsigned long i); /* (beg, i) int beg; int i; */
@@ -368,7 +369,7 @@ typedef void (*funcvoid)(void);
 /* num_comp.c:272:OF */ extern void Lmonotonically_nonincreasing (void); /* () */
 /* num_comp.c:292:OF */ extern void Lmin (void); /* () */
 /* num_comp.c:309:OF */ extern void gcl_init_num_comp (void); /* () */
-/* num_log.c:224:OF */ extern object shift_integer (object x, int w); /* (x, w) object x; int w; */
+/* num_log.c:224:OF */ extern object shift_integer (object x, fixnum w); /* (x, w) object x; int w; */
 /* num_log.c:258:OF */ extern void Llogior (void); /* () */
 /* num_log.c:279:OF */ extern void Llogxor (void); /* () */
 /* num_log.c:299:OF */ extern void Llogand (void); /* () */
@@ -1836,3 +1837,10 @@ int
 obj_to_mpz(object,MP_INT *);
 
 struct htent *gethash(object,object);
+
+int
+update_real_maxpage(void);
+
+fixnum
+set_tm_maxpage(struct typemanager *,fixnum);
+
